import requests
import json


def get_related_records(token, module, record_id, related_list, **kwargs):
    url = f"https://www.zohoapis.com/crm/v2.1/{module}/{record_id}/{related_list}"

    headers = {
        "Authorization": f'Zoho-oauthtoken {token.access}'
    }
    response = requests.get(url=url, headers=headers, params=kwargs)

    if response.status_code == 400:
        token.generate()
        print("Auth")
        return get_related_records(token, module, record_id, related_list, **kwargs)

    else:
        content = json.loads(response.content.decode('utf-8'))
        data = content.get("data")
        return token, data


def update_related_record(token, module, record_id, related_list, related_id, data_object):
    url = f'https://www.zohoapis.com/crm/v2.1/{module}/{record_id}/{related_list}'
    headers = {
        'Authorization': f'Zoho-oauthtoken {token.access}'
    }
    data_object['id'] = related_id
    request_body = {}
    record_list = [data_object]

    request_body['data'] = record_list
    data = json.dumps(request_body).encode('utf-8')
    
    response = requests.put(url=url, headers=headers,data=data)

    if response.status_code == 400:
        print("Auth")
        token.generate()
        return update_related_record(token, module, record_id, related_list, related_id, data_object)

    else:
        content = json.loads(response.content.decode('utf-8'))
        return token, response.status_code, content





import requests
import json


def get_roles(token):
    url = 'https://www.zohoapis.com/crm/v2.1/settings/roles'
    headers = {'Authorization': f'Zoho-oauthtoken {token.access}'}

    response = requests.get(url=url, headers=headers)

    if response.status_code == 400:
        token.generate()
        return get_roles(token)

    else:
        content = json.loads(response.content.decode('utf-8'))
        return token, content.get("roles")


def get_role(token, role_id):
    url = f'https://www.zohoapis.com/crm/v2.1/settings/roles/{role_id}'
    headers = {'Authorization': f'Zoho-oauthtoken {token.access}'}

    response = requests.get(url=url, headers=headers)

    if response.status_code == 400:
        token.generate()
        return get_role(token, role_id)

    else:
        content = json.loads(response.content.decode('utf-8'))
        return token, content.get("roles")






import requests
import json


def get_attachments(token, module, record_id, **kwargs):
    url = f'https://www.zohoapis.com/crm/v2/{module}/{record_id}/Attachments'
    headers = {
        'Authorization': f'Zoho-oauthtoken {token.access}'
    }
    response = requests.get(url=url, headers=headers, params=kwargs)

    if response.status_code == 400:
        print("Auth")
        token.generate()
        return get_attachments(token, module, record_id, **kwargs)

    else:
        content = json.loads(response.content.decode('utf-8'))
        return token, content.get("data")






from setuptools import setup, find_packages


VERSION = '0.1.1'
DESCRIPTION = "Implementation tools for Zoho CRM"
LONG_DESCRIPTION = "A pet project I'm working, makes API calls to Zoho APIS"

setup(
    name="zohoSolCon",
    version=VERSION,
    author="Dylan Garrett",
    author_email="dylan.g@zohocorp.com",
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    keywords=['zoho', 'crm', 'api']
)



import requests
import json


def get_org_details(token):
    url = "https://www.zohoapis.com/crm/v2.1/org"

    headers = {
        "Authorization": f"Zoho-oauthtoken {token.access}"
    }
    response = requests.get(url=url, headers=headers)

    if response.status_code == 400:
        token.generate()
        return get_org_details(token)

    else:
        content = json.loads(response.content.decode('utf-8'))
        org = content.get("org")
        return token, org





import requests
import json


def get_tags(token, **kwargs):
    url = 'https://www.zohoapis.com/crm/v2/settings/tags'
    headers = {
        'Authorization': f'Zoho-oauthtoken {token.access}'
    }
    response = requests.get(url=url, headers=headers, params=kwargs)

    if response.status_code == 400:
        print("Auth")
        token.generate()
        return get_tags(token, **kwargs)

    else:
        content = json.loads(response.content.decode('utf-8'))
        return token, content.get('tags')

def tag_record(token, module, record_id, tag_list, over_write=True):
    url = f'https://www.zohoapis.com/crm/v2.1/{modules}/actions/add_tags?ids={record_id}&tag_names='
    for tag in tag_list:
        if tag == tag_list[-1]:
            url += tag
        else:
            url += tag + ','
        if over_write:
            url += "&over_write=true"
        else:
            url += '&over_write=false'
            
    headers = {
        'Authorization': f'Zoho-oauthtoken {token.access}'
    }
    response = requests.post(url=url, headers=headers)

    if response.status_code == 400:
        print("Auth")
        token.generate()
        return tag_record(token, module, record_id, tag_list, over_write=over_write)

    else:
        content = json.loads(response.content.decode('utf-8'))
        return token, response.status_code, content


def remove_tags(token, module, record_id, tag_list):
    url = f'https://www.zohoapis.com/crm/v2.1/{modules}/actions/remove_tags?ids={record_id}&tag_names='
    for tag in tag_list:
        if tag == tag_list[-1]:
            url += tag
        else:
            url += tag + ','

    headers = {
        'Authorization': f'Zoho-oauthtoken {token.access}'
    }
    response = requests.post(url=url, headers=headers)

    if response.status_code == 400:
        print("Auth")
        token.generate()
        return tag_record(token, module, record_id, tag_list, over_write=over_write)

    else:
        content = json.loads(response.content.decode('utf-8'))
        return token, response.status_code, content


def count_record_tags(token, module, tag_id):
    url = f'https://www.zohoapis.com/crm/v2/settings/{tag_id}/actions/records_count'
    headers = {
        'Authorization': f'Zoho-oauthtoken {token.access}'
    }
    parameters = {'module': module}

    response = requests.get(url=url, headers=headers, params=parameters)

    if response.status_code == 400:
        print("Auth")
        token.generate()
        return count_record_tags(token, module, tag_id)

    else:
        content = json.loads(response.content.decode('utf-8'))
        return token, int(content.get('count'))





import requests
import json


def get_users(token, **kwargs):
    url = "https://www.zohoapis.com/crm/v2.1/users"

    headers = {
        "Authorization": f"Zoho-oauthtoken {token.access}"
    }

    response = requests.get(url=url, headers=headers, params=kwargs)

    if response.status_code == 400:
        token.generate()
        return get_users(token, **kwargs)

    else:
        content = json.loads(response.content.decode('utf-8'))
        return token, content.get("users")


def add_user(token, user_object):
    url = 'https://www.zohoapis.com/crm/v2.1/users'

    headers = {
        'Authorization': f'Zoho-oauthtoken {token.access}'
    }

    request_body = {}
    user_list = [user_object]

    request_body['users'] = user_list

    data = json.dumps(request_body).encode('utf-8')

    response = requests.post(url=url, headers=headers,data=data)

    if response.status_code == 400:
        token.generate()
        return add_user(token, user_object)

    else:
        return token, response.status_code, json.loads(response.content.decode('utf-8'))


